@@ -1,22 +1,25 @@
 use crate::error::Result;
 use regex::Regex;
+use std::path::Path;
 
 /// Configuration values.
-#[derive(Debug, Clone, serde_derive::Serialize, serde_derive::Deserialize)]
+#[derive(Debug, Clone, serde::Serialize, serde::Deserialize)]
 pub struct Config {
 	/// Configuration values about changelog generation.
+	#[serde(default)]
 	pub changelog: ChangelogConfig,
 	/// Configuration values about git.
+	#[serde(default)]
 	pub git:       GitConfig,
 }
 
 /// Changelog configuration.
-#[derive(Debug, Clone, serde_derive::Serialize, serde_derive::Deserialize)]
+#[derive(Debug, Default, Clone, serde::Serialize, serde::Deserialize)]
 pub struct ChangelogConfig {
 	/// Changelog header.
 	pub header: Option<String>,
 	/// Changelog body, template.
-	pub body:   String,
+	pub body:   Option<String>,
 	/// Changelog footer.
 	pub footer: Option<String>,
 	/// Trim the template.
@@ -24,14 +27,16 @@ pub struct ChangelogConfig {
 }
 
 /// Git configuration
-#[derive(Debug, Clone, serde_derive::Serialize, serde_derive::Deserialize)]
+#[derive(Debug, Default, Clone, serde::Serialize, serde::Deserialize)]
 pub struct GitConfig {
 	/// Whether to enable parsing conventional commits.
-	pub conventional_commits:  bool,
+	pub conventional_commits:  Option<bool>,
 	/// Whether to filter out unconventional commits.
 	pub filter_unconventional: Option<bool>,
 	/// Git commit parsers.
 	pub commit_parsers:        Option<Vec<CommitParser>>,
+	/// Link parsers.
+	pub link_parsers:          Option<Vec<LinkParser>>,
 	/// Whether to filter out commits.
 	pub filter_commits:        Option<bool>,
 	/// Blob pattern for git tags.
@@ -42,14 +47,14 @@ pub struct GitConfig {
 	#[serde(with = "serde_regex", default)]
 	/// Regex to ignore matched tags.
 	pub ignore_tags:           Option<Regex>,
-	/// Whether to sort tags topologically.
-	pub topo_order:            Option<bool>,
+	/// Whether to sort tags chronologically.
+	pub date_order:            Option<bool>,
 	/// Sorting of the commits inside sections.
 	pub sort_commits:          Option<String>,
 }
 
 /// Parser for grouping commits.
-#[derive(Debug, Clone, serde_derive::Serialize, serde_derive::Deserialize)]
+#[derive(Debug, Clone, serde::Serialize, serde::Deserialize)]
 pub struct CommitParser {
 	/// Regex for matching the commit message.
 	#[serde(with = "serde_regex", default)]
@@ -65,12 +70,24 @@ pub struct CommitParser {
 	pub skip:          Option<bool>,
 }
 
+/// Parser for extracting links in commits.
+#[derive(Debug, Clone, serde::Serialize, serde::Deserialize)]
+pub struct LinkParser {
+	/// Regex for finding links in the commit message.
+	#[serde(with = "serde_regex")]
+	pub pattern: Regex,
+	/// The string used to generate the link URL.
+	pub href:    String,
+	/// The string used to generate the link text.
+	pub text:    Option<String>,
+}
+
 impl Config {
 	/// Parses the config file and returns the values.
-	pub fn parse(file_name: String) -> Result<Config> {
+	pub fn parse(path: &Path) -> Result<Config> {
 		let mut config = config::Config::default();
 		config
-			.merge(config::File::with_name(&file_name))?
+			.merge(config::File::from(path))?
 			.merge(config::Environment::with_prefix("CLIFF").separator("_"))?;
 		Ok(config.try_into()?)
 	}
@@ -84,17 +101,14 @@ mod test {
 	use std::path::PathBuf;
 	#[test]
 	fn parse_config() -> Result<()> {
-		let file_name = PathBuf::from(env!("CARGO_MANIFEST_DIR"))
+		let path = PathBuf::from(env!("CARGO_MANIFEST_DIR"))
 			.parent()
 			.unwrap()
 			.to_path_buf()
 			.join("config")
-			.join(crate::DEFAULT_CONFIG)
-			.to_str()
-			.unwrap()
-			.to_string();
+			.join(crate::DEFAULT_CONFIG);
 		env::set_var("CLIFF_CHANGELOG_FOOTER", "test");
-		let config = Config::parse(file_name)?;
+		let config = Config::parse(&path)?;
 		assert_eq!("test", config.changelog.footer.unwrap());
 		Ok(())
 	}
