@@ -6,8 +6,13 @@ pub mod changelog;
 #[macro_use]
 extern crate log;
 
-use args::Opt;
+use args::{
+	Opt,
+	Sort,
+	Strip,
+};
 use changelog::Changelog;
+use clap::ArgEnum;
 use git_cliff_core::commit::Commit;
 use git_cliff_core::config::Config;
 use git_cliff_core::embed::EmbeddedConfig;
@@ -47,43 +52,43 @@ pub fn run(mut args: Opt) -> Result<()> {
 	}
 
 	// Parse the configuration file.
-	let mut path = match args.config.to_str() {
-		Some(v) => Ok(v.to_string()),
-		None => Err(Error::IoError(io::Error::new(
-			io::ErrorKind::Other,
-			"path contains invalid characters",
-		))),
-	}?;
-	if let Some(config_path) = dirs_next::config_dir()
-		.map(|dir| dir.join(env!("CARGO_PKG_NAME")).join(DEFAULT_CONFIG))
-		.map(|path| path.to_str().map(String::from))
-		.flatten()
-	{
-		if fs::metadata(&config_path).is_ok() {
+	let mut path = args.config.clone();
+	if !path.exists() {
+		if let Some(config_path) = dirs_next::config_dir()
+			.map(|dir| dir.join(env!("CARGO_PKG_NAME")).join(DEFAULT_CONFIG))
+		{
 			path = config_path;
 		}
 	}
 
-	let mut config = if fs::metadata(&path).is_ok() {
-		Config::parse(path)?
+	// Load the default configuration if necessary.
+	let mut config = if path.exists() {
+		Config::parse(&path)?
 	} else {
-		warn!("{:?} is not found, using the default configuration.", path);
+		warn!(
+			"{:?} is not found, using the default configuration.",
+			args.config
+		);
 		EmbeddedConfig::parse()?
 	};
+	if config.changelog.body.is_none() {
+		warn!("Changelog body is not specified, using the default template.");
+		config.changelog.body = EmbeddedConfig::parse()?.changelog.body;
+	}
 
 	// Update the configuration based on command line arguments and vice versa.
-	match args.strip.as_deref() {
-		Some("header") => {
+	match args.strip {
+		Some(Strip::Header) => {
 			config.changelog.header = None;
 		}
-		Some("footer") => {
+		Some(Strip::Footer) => {
 			config.changelog.footer = None;
 		}
-		Some("all") => {
+		Some(Strip::All) => {
 			config.changelog.header = None;
 			config.changelog.footer = None;
 		}
-		_ => {}
+		None => {}
 	}
 	if args.prepend.is_some() {
 		config.changelog.footer = None;
@@ -93,17 +98,18 @@ pub fn run(mut args: Opt) -> Result<()> {
 			)));
 		}
 	}
-	if let Some(template) = args.body {
-		config.changelog.body = template;
+	if args.body.is_some() {
+		config.changelog.body = args.body;
 	}
-	if args.sort == "oldest" {
+	if args.sort == Sort::Oldest {
 		if let Some(ref sort_commits) = config.git.sort_commits {
-			args.sort = sort_commits.to_string();
+			args.sort = Sort::from_str(sort_commits, true)
+				.expect("Incorrect config value for 'sort_commits'");
 		}
 	}
-	if !args.topo_order {
-		if let Some(topo_order) = config.git.topo_order {
-			args.topo_order = topo_order;
+	if !args.date_order {
+		if let Some(date_order) = config.git.date_order {
+			args.date_order = date_order;
 		}
 	}
 
@@ -112,7 +118,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 		Repository::init(args.repository.unwrap_or(env::current_dir()?))?;
 
 	// Parse tags.
-	let mut tags = repository.tags(&config.git.tag_pattern, args.topo_order)?;
+	let mut tags = repository.tags(&config.git.tag_pattern, args.date_order)?;
 
 	// Skip tags.
 	let skip_regex = config.git.skip_tags.as_ref();
@@ -200,7 +206,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 	for git_commit in commits.into_iter().rev() {
 		let commit = Commit::from(&git_commit);
 		let commit_id = commit.id.to_string();
-		if args.sort == "newest" {
+		if args.sort == Sort::Newest {
 			releases[release_index].commits.insert(0, commit);
 		} else {
 			releases[release_index].commits.push(commit);
@@ -229,8 +235,10 @@ pub fn run(mut args: Opt) -> Result<()> {
 	}
 
 	// Set the previous release if needed.
-	if args.latest {
-		if let Some((commit_id, version)) = tags.get_index(tags.len() - 2) {
+	if args.latest || args.unreleased {
+		if let Some((commit_id, version)) =
+			tags.len().checked_sub(2).and_then(|v| tags.get_index(v))
+		{
 			let previous_release = Release {
 				commit_id: Some(commit_id.to_string()),
 				version: Some(version.to_string()),
